==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/opensshd/opensshd.h <==
#ifndef opensshd_h
#define opensshd_h
#pragma interface
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_opensshd: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_opensshd */
public:
	MODULE_opensshd (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[]);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_opensshd */
};

class OPENSSHD_OPTIONS
{
public:
	SSTRING AFSTokenPassing;
	SSTRING AllowGroups;
	SSTRING AllowUsers;
	SSTRING CheckMail;
	SSTRING Ciphers;
	SSTRING DenyGroups;
	SSTRING DenyUsers;
	SSTRING DSAAuthentication;
	SSTRING GatewayPorts;
	SSTRING HostDsaKey;
	SSTRING HostKey;
	SSTRING IgnoreRhosts;
	SSTRING IgnoreUserKnownHosts;
	SSTRING KeepAlive;
	SSTRING KerberosAuthentication;
	SSTRING KerberosOrLocalPasswd;
	SSTRING KerberosTgtPassing;
	SSTRING KerberosTicketCleanup;
	SSTRING KeyRegenerationInterval;
	SSTRING ListenAddress;
	SSTRING LoginGraceTime;
	SSTRING LogLevel;
	SSTRING PasswordAuthentication;
	SSTRING PermitEmptyPasswords;
	SSTRING PermitRootLogin;
	SSTRING PidFile;
	SSTRING Port;
	SSTRING PrintMotd;
	SSTRING Protocol;
	SSTRING RhostsAuthentication;
	SSTRING RhostsRSAAuthentication;
	SSTRING RSAAuthentication;
	SSTRING ServerKeyBits;
	SSTRING SkeyAuthentication;
	SSTRING StrictModes;
	SSTRING SyslogFacility;
	SSTRING UseLogin;
	SSTRING X11DisplayOffset;
	SSTRING X11Forwarding;
};

#include "opensshdviewitems.h"
#include "opensshd.p"

#endif

==> linuxconf-1.26r2.src.tar.gz: linuxconf-1.26r2/modules/opensshd/opensshd.h <==
#ifndef opensshd_h
#define opensshd_h
#pragma interface
#ifndef MISC_H
    #include <misc.h>
    #include <fviews.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>

class MODULE_opensshd: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_opensshd */
public:
	MODULE_opensshd (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_opensshd */
};

class OPENSSHD_OPTIONS
{
public:
	SSTRING AFSTokenPassing;
	SSTRING AllowGroups;
	SSTRING AllowUsers;
	SSTRING CheckMail;
	SSTRING Ciphers;
	SSTRING DenyGroups;
	SSTRING DenyUsers;
	SSTRING DSAAuthentication;
	SSTRING GatewayPorts;
	SSTRING HostDsaKey;
	SSTRING HostKey;
	SSTRING IgnoreRhosts;
	SSTRING IgnoreUserKnownHosts;
	SSTRING KeepAlive;
	SSTRING KerberosAuthentication;
	SSTRING KerberosOrLocalPasswd;
	SSTRING KerberosTgtPassing;
	SSTRING KerberosTicketCleanup;
	SSTRING KeyRegenerationInterval;
	SSTRING ListenAddress;
	SSTRING LoginGraceTime;
	SSTRING LogLevel;
	SSTRING PasswordAuthentication;
	SSTRING PermitEmptyPasswords;
	SSTRING PermitRootLogin;
	SSTRING PidFile;
	SSTRING Port;
	SSTRING PrintMotd;
	SSTRING Protocol;
	SSTRING RhostsAuthentication;
	SSTRING RhostsRSAAuthentication;
	SSTRING RSAAuthentication;
	SSTRING ServerKeyBits;
	SSTRING SkeyAuthentication;
	SSTRING StrictModes;
	SSTRING SyslogFacility;
	SSTRING UseLogin;
	SSTRING X11DisplayOffset;
	SSTRING X11Forwarding;
};

#include "opensshd.p"

#endif
